summaryrefslogtreecommitdiffstats
path: root/lib/util/execcommand.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/util/execcommand.h')
-rw-r--r--lib/util/execcommand.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/lib/util/execcommand.h b/lib/util/execcommand.h
index c00085c6..c3e20d47 100644
--- a/lib/util/execcommand.h
+++ b/lib/util/execcommand.h
@@ -20,8 +20,8 @@
#ifndef _EXECCOMMAND_H_
#define _EXECCOMMAND_H_
-#include <qobject.h>
-#include <qstringlist.h>
+#include <tqobject.h>
+#include <tqstringlist.h>
class KProcess;
class KProgressDialog;
@@ -37,22 +37,22 @@ Command execution facilities.
* a progress dialog with the possibility to cancel the command.
*
* If there was an error or the user pressed cancel, finished ()
* will emit a QString::null, otherwise QStrings containing the stdout/stderr.
*
* The object will delete itself after the finished signal has been emitted.
* Additional environment can be set in the QStringList env via QStrings with the format "foo=blah"
*/
class ExecCommand : public QObject
{
Q_OBJECT
public:
- ExecCommand( const QString& executable, const QStringList& args,
- const QString& workingDir = QString::null,
- const QStringList& env = QStringList(), QObject* parent = 0, const char* name = 0 );
+ ExecCommand( const TQString& executable, const TQStringList& args,
+ const TQString& workingDir = TQString::null,
+ const TQStringList& env = TQStringList(), TQObject* parent = 0, const char* name = 0 );
~ExecCommand();
signals:
- void finished( const QString& output, const QString& errorOutput );
+ void finished( const TQString& output, const TQString& errorOutput );
private slots:
void receivedStdout (KProcess *, char *buffer, int buflen);
@@ -63,8 +63,8 @@ private slots:
private:
KProcess* proc;
KProgressDialog* progressDlg;
- QString out;
- QString err;
+ TQString out;
+ TQString err;
};
#endif
@@ -37,22 +37,22 @@ Command execution facilities.
*
* If there was an error or the user pressed cancel, finished ()
- * will emit a QString::null, otherwise QStrings containing the stdout/stderr.
+ * will emit a TQString::null, otherwise QStrings containing the stdout/stderr.
*
* The object will delete itself after the finished signal has been emitted.
@@ -37,22 +37,22 @@ Command execution facilities.
*
* The object will delete itself after the finished signal has been emitted.
- * Additional environment can be set in the QStringList env via QStrings with the format "foo=blah"
+ * Additional environment can be set in the TQStringList env via QStrings with the format "foo=blah"
*/
class ExecCommand : public QObject